@@ -1,42 +1,41 @@
 from http import HTTPStatus
-from typing import Any, Dict, Optional
+from typing import Any, Dict, Optional, Union
 
 import httpx
 
 from ... import errors
-from ...client import Client
-from ...models.post_chart_results_json_body import PostChartResultsJsonBody
-from ...models.post_chart_results_response_200 import PostChartResultsResponse200
+from ...client import AuthenticatedClient, Client
+from ...models.api_run_query_response import ApiRunQueryResponse
+from ...models.post_chart_results_body import PostChartResultsBody
 from ...types import Response
 
 
 def _get_kwargs(
     chart_uuid: str,
     *,
-    client: Client,
-    json_body: PostChartResultsJsonBody,
+    body: PostChartResultsBody,
 ) -> Dict[str, Any]:
-    url = "{}/api/v1/saved/{chartUuid}/results".format(client.base_url, chartUuid=chart_uuid)
+    headers: Dict[str, Any] = {}
 
-    headers: Dict[str, str] = client.get_headers()
-    cookies: Dict[str, Any] = client.get_cookies()
-
-    json_json_body = json_body.to_dict()
-
-    return {
+    _kwargs: Dict[str, Any] = {
         "method": "post",
-        "url": url,
-        "headers": headers,
-        "cookies": cookies,
-        "timeout": client.get_timeout(),
-        "follow_redirects": client.follow_redirects,
-        "json": json_json_body,
+        "url": f"/api/v1/saved/{chart_uuid}/results",
     }
 
+    _body = body.to_dict()
 
-def _parse_response(*, client: Client, response: httpx.Response) -> Optional[PostChartResultsResponse200]:
+    _kwargs["json"] = _body
+    headers["Content-Type"] = "application/json"
+
+    _kwargs["headers"] = headers
+    return _kwargs
+
+
+def _parse_response(
+    *, client: Union[AuthenticatedClient, Client], response: httpx.Response
+) -> Optional[ApiRunQueryResponse]:
     if response.status_code == HTTPStatus.OK:
-        response_200 = PostChartResultsResponse200.from_dict(response.json())
+        response_200 = ApiRunQueryResponse.from_dict(response.json())
 
         return response_200
     if client.raise_on_unexpected_status:
@@ -45,7 +44,9 @@ def _parse_response(*, client: Client, response: httpx.Response) -> Optional[Pos
         return None
 
 
-def _build_response(*, client: Client, response: httpx.Response) -> Response[PostChartResultsResponse200]:
+def _build_response(
+    *, client: Union[AuthenticatedClient, Client], response: httpx.Response
+) -> Response[ApiRunQueryResponse]:
     return Response(
         status_code=HTTPStatus(response.status_code),
         content=response.content,
@@ -57,31 +58,29 @@ def _build_response(*, client: Client, response: httpx.Response) -> Response[Pos
 def sync_detailed(
     chart_uuid: str,
     *,
-    client: Client,
-    json_body: PostChartResultsJsonBody,
-) -> Response[PostChartResultsResponse200]:
+    client: Union[AuthenticatedClient, Client],
+    body: PostChartResultsBody,
+) -> Response[ApiRunQueryResponse]:
     """Run a query for a chart
 
     Args:
         chart_uuid (str):
-        json_body (PostChartResultsJsonBody):
+        body (PostChartResultsBody):
 
     Raises:
         errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
         httpx.TimeoutException: If the request takes longer than Client.timeout.
 
     Returns:
-        Response[PostChartResultsResponse200]
+        Response[ApiRunQueryResponse]
     """
 
     kwargs = _get_kwargs(
         chart_uuid=chart_uuid,
-        client=client,
-        json_body=json_body,
+        body=body,
     )
 
-    response = httpx.request(
-        verify=client.verify_ssl,
+    response = client.get_httpx_client().request(
         **kwargs,
     )
 
@@ -91,58 +90,56 @@ def sync_detailed(
 def sync(
     chart_uuid: str,
     *,
-    client: Client,
-    json_body: PostChartResultsJsonBody,
-) -> Optional[PostChartResultsResponse200]:
+    client: Union[AuthenticatedClient, Client],
+    body: PostChartResultsBody,
+) -> Optional[ApiRunQueryResponse]:
     """Run a query for a chart
 
     Args:
         chart_uuid (str):
-        json_body (PostChartResultsJsonBody):
+        body (PostChartResultsBody):
 
     Raises:
         errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
         httpx.TimeoutException: If the request takes longer than Client.timeout.
 
     Returns:
-        PostChartResultsResponse200
+        ApiRunQueryResponse
     """
 
     return sync_detailed(
         chart_uuid=chart_uuid,
         client=client,
-        json_body=json_body,
+        body=body,
     ).parsed
 
 
 async def asyncio_detailed(
     chart_uuid: str,
     *,
-    client: Client,
-    json_body: PostChartResultsJsonBody,
-) -> Response[PostChartResultsResponse200]:
+    client: Union[AuthenticatedClient, Client],
+    body: PostChartResultsBody,
+) -> Response[ApiRunQueryResponse]:
     """Run a query for a chart
 
     Args:
         chart_uuid (str):
-        json_body (PostChartResultsJsonBody):
+        body (PostChartResultsBody):
 
     Raises:
         errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
         httpx.TimeoutException: If the request takes longer than Client.timeout.
 
     Returns:
-        Response[PostChartResultsResponse200]
+        Response[ApiRunQueryResponse]
     """
 
     kwargs = _get_kwargs(
         chart_uuid=chart_uuid,
-        client=client,
-        json_body=json_body,
+        body=body,
     )
 
-    async with httpx.AsyncClient(verify=client.verify_ssl) as _client:
-        response = await _client.request(**kwargs)
+    response = await client.get_async_httpx_client().request(**kwargs)
 
     return _build_response(client=client, response=response)
 
@@ -150,27 +147,27 @@ async def asyncio_detailed(
 async def asyncio(
     chart_uuid: str,
     *,
-    client: Client,
-    json_body: PostChartResultsJsonBody,
-) -> Optional[PostChartResultsResponse200]:
+    client: Union[AuthenticatedClient, Client],
+    body: PostChartResultsBody,
+) -> Optional[ApiRunQueryResponse]:
     """Run a query for a chart
 
     Args:
         chart_uuid (str):
-        json_body (PostChartResultsJsonBody):
+        body (PostChartResultsBody):
 
     Raises:
         errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
         httpx.TimeoutException: If the request takes longer than Client.timeout.
 
     Returns:
-        PostChartResultsResponse200
+        ApiRunQueryResponse
     """
 
     return (
         await asyncio_detailed(
             chart_uuid=chart_uuid,
             client=client,
-            json_body=json_body,
+            body=body,
         )
     ).parsed
