@@ -1,39 +1,30 @@
 from http import HTTPStatus
-from typing import Any
-from typing import Dict
-from typing import Optional
+from typing import Any, Dict, Optional, Union
 
 import httpx
 
 from ... import errors
-from ...client import Client
-from ...models.get_scheduled_jobs_response_200 import GetScheduledJobsResponse200
+from ...client import AuthenticatedClient, Client
+from ...models.api_scheduled_jobs_response import ApiScheduledJobsResponse
 from ...types import Response
 
 
 def _get_kwargs(
     scheduler_uuid: str,
-    *,
-    client: Client,
 ) -> Dict[str, Any]:
-    url = "{}/api/v1/schedulers/{schedulerUuid}/jobs".format(client.base_url, schedulerUuid=scheduler_uuid)
-
-    headers: Dict[str, str] = client.get_headers()
-    cookies: Dict[str, Any] = client.get_cookies()
-
-    return {
+    _kwargs: Dict[str, Any] = {
         "method": "get",
-        "url": url,
-        "headers": headers,
-        "cookies": cookies,
-        "timeout": client.get_timeout(),
-        "follow_redirects": client.follow_redirects,
+        "url": f"/api/v1/schedulers/{scheduler_uuid}/jobs",
     }
 
+    return _kwargs
 
-def _parse_response(*, client: Client, response: httpx.Response) -> Optional[GetScheduledJobsResponse200]:
+
+def _parse_response(
+    *, client: Union[AuthenticatedClient, Client], response: httpx.Response
+) -> Optional[ApiScheduledJobsResponse]:
     if response.status_code == HTTPStatus.OK:
-        response_200 = GetScheduledJobsResponse200.from_dict(response.json())
+        response_200 = ApiScheduledJobsResponse.from_dict(response.json())
 
         return response_200
     if client.raise_on_unexpected_status:
@@ -42,7 +33,9 @@ def _parse_response(*, client: Client, response: httpx.Response) -> Optional[Get
         return None
 
 
-def _build_response(*, client: Client, response: httpx.Response) -> Response[GetScheduledJobsResponse200]:
+def _build_response(
+    *, client: Union[AuthenticatedClient, Client], response: httpx.Response
+) -> Response[ApiScheduledJobsResponse]:
     return Response(
         status_code=HTTPStatus(response.status_code),
         content=response.content,
@@ -54,8 +47,8 @@ def _build_response(*, client: Client, response: httpx.Response) -> Response[Get
 def sync_detailed(
     scheduler_uuid: str,
     *,
-    client: Client,
-) -> Response[GetScheduledJobsResponse200]:
+    client: Union[AuthenticatedClient, Client],
+) -> Response[ApiScheduledJobsResponse]:
     """Get scheduled jobs
 
     Args:
@@ -66,16 +59,14 @@ def sync_detailed(
         httpx.TimeoutException: If the request takes longer than Client.timeout.
 
     Returns:
-        Response[GetScheduledJobsResponse200]
+        Response[ApiScheduledJobsResponse]
     """
 
     kwargs = _get_kwargs(
         scheduler_uuid=scheduler_uuid,
-        client=client,
     )
 
-    response = httpx.request(
-        verify=client.verify_ssl,
+    response = client.get_httpx_client().request(
         **kwargs,
     )
 
@@ -85,8 +76,8 @@ def sync_detailed(
 def sync(
     scheduler_uuid: str,
     *,
-    client: Client,
-) -> Optional[GetScheduledJobsResponse200]:
+    client: Union[AuthenticatedClient, Client],
+) -> Optional[ApiScheduledJobsResponse]:
     """Get scheduled jobs
 
     Args:
@@ -97,7 +88,7 @@ def sync(
         httpx.TimeoutException: If the request takes longer than Client.timeout.
 
     Returns:
-        GetScheduledJobsResponse200
+        ApiScheduledJobsResponse
     """
 
     return sync_detailed(
@@ -109,8 +100,8 @@ def sync(
 async def asyncio_detailed(
     scheduler_uuid: str,
     *,
-    client: Client,
-) -> Response[GetScheduledJobsResponse200]:
+    client: Union[AuthenticatedClient, Client],
+) -> Response[ApiScheduledJobsResponse]:
     """Get scheduled jobs
 
     Args:
@@ -121,16 +112,14 @@ async def asyncio_detailed(
         httpx.TimeoutException: If the request takes longer than Client.timeout.
 
     Returns:
-        Response[GetScheduledJobsResponse200]
+        Response[ApiScheduledJobsResponse]
     """
 
     kwargs = _get_kwargs(
         scheduler_uuid=scheduler_uuid,
-        client=client,
     )
 
-    async with httpx.AsyncClient(verify=client.verify_ssl) as _client:
-        response = await _client.request(**kwargs)
+    response = await client.get_async_httpx_client().request(**kwargs)
 
     return _build_response(client=client, response=response)
 
@@ -138,8 +127,8 @@ async def asyncio_detailed(
 async def asyncio(
     scheduler_uuid: str,
     *,
-    client: Client,
-) -> Optional[GetScheduledJobsResponse200]:
+    client: Union[AuthenticatedClient, Client],
+) -> Optional[ApiScheduledJobsResponse]:
     """Get scheduled jobs
 
     Args:
@@ -150,7 +139,7 @@ async def asyncio(
         httpx.TimeoutException: If the request takes longer than Client.timeout.
 
     Returns:
-        GetScheduledJobsResponse200
+        ApiScheduledJobsResponse
     """
 
     return (
