@@ -1,30 +1,38 @@
-from typing import TYPE_CHECKING, Any, Dict, List, Type, TypeVar
+from typing import TYPE_CHECKING, Any, Dict, List, Type, TypeVar, Union
 
-import attr
+from attrs import define as _attrs_define
+from attrs import field as _attrs_field
 
 from ..models.api_group_response_status import ApiGroupResponseStatus
 
 if TYPE_CHECKING:
-    from ..models.api_group_response_results import ApiGroupResponseResults
+    from ..models.group import Group
+    from ..models.group_with_members import GroupWithMembers
 
 
 T = TypeVar("T", bound="ApiGroupResponse")
 
 
-@attr.s(auto_attribs=True)
+@_attrs_define
 class ApiGroupResponse:
     """
     Attributes:
-        results (ApiGroupResponseResults):
+        results (Union['Group', 'GroupWithMembers']):
         status (ApiGroupResponseStatus):
     """
 
-    results: "ApiGroupResponseResults"
+    results: Union["Group", "GroupWithMembers"]
     status: ApiGroupResponseStatus
-    additional_properties: Dict[str, Any] = attr.ib(init=False, factory=dict)
+    additional_properties: Dict[str, Any] = _attrs_field(init=False, factory=dict)
 
     def to_dict(self) -> Dict[str, Any]:
-        results = self.results.to_dict()
+        from ..models.group import Group
+
+        results: Dict[str, Any]
+        if isinstance(self.results, Group):
+            results = self.results.to_dict()
+        else:
+            results = self.results.to_dict()
 
         status = self.status.value
 
@@ -41,10 +49,27 @@ class ApiGroupResponse:
 
     @classmethod
     def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
-        from ..models.api_group_response_results import ApiGroupResponseResults
+        from ..models.group import Group
+        from ..models.group_with_members import GroupWithMembers
 
         d = src_dict.copy()
-        results = ApiGroupResponseResults.from_dict(d.pop("results"))
+
+        def _parse_results(data: object) -> Union["Group", "GroupWithMembers"]:
+            try:
+                if not isinstance(data, dict):
+                    raise TypeError()
+                results_type_0 = Group.from_dict(data)
+
+                return results_type_0
+            except:  # noqa: E722
+                pass
+            if not isinstance(data, dict):
+                raise TypeError()
+            results_type_1 = GroupWithMembers.from_dict(data)
+
+            return results_type_1
+
+        results = _parse_results(d.pop("results"))
 
         status = ApiGroupResponseStatus(d.pop("status"))
 
