@@ -1,6 +1,7 @@
 from typing import TYPE_CHECKING, Any, Dict, List, Type, TypeVar
 
-import attr
+from attrs import define as _attrs_define
+from attrs import field as _attrs_field
 
 from ..models.api_job_scheduled_response_status import ApiJobScheduledResponseStatus
 
@@ -13,7 +14,7 @@ if TYPE_CHECKING:
 T = TypeVar("T", bound="ApiJobScheduledResponse")
 
 
-@attr.s(auto_attribs=True)
+@_attrs_define
 class ApiJobScheduledResponse:
     """
     Attributes:
@@ -23,7 +24,7 @@ class ApiJobScheduledResponse:
 
     results: "ApiJobScheduledResponseResults"
     status: ApiJobScheduledResponseStatus
-    additional_properties: Dict[str, Any] = attr.ib(init=False, factory=dict)
+    additional_properties: Dict[str, Any] = _attrs_field(init=False, factory=dict)
 
     def to_dict(self) -> Dict[str, Any]:
         results = self.results.to_dict()
