@@ -1,13 +1,14 @@
 import datetime
 from typing import Any, Dict, List, Type, TypeVar
 
-import attr
+from attrs import define as _attrs_define
+from attrs import field as _attrs_field
 from dateutil.parser import isoparse
 
 T = TypeVar("T", bound="Group")
 
 
-@attr.s(auto_attribs=True)
+@_attrs_define
 class Group:
     """
     Attributes:
@@ -21,13 +22,15 @@ class Group:
     created_at: datetime.datetime
     name: str
     uuid: str
-    additional_properties: Dict[str, Any] = attr.ib(init=False, factory=dict)
+    additional_properties: Dict[str, Any] = _attrs_field(init=False, factory=dict)
 
     def to_dict(self) -> Dict[str, Any]:
         organization_uuid = self.organization_uuid
+
         created_at = self.created_at.isoformat()
 
         name = self.name
+
         uuid = self.uuid
 
         field_dict: Dict[str, Any] = {}
